package org.bioapi;

import java.util.Vector;

import org.bioapi.data.GUIBitmap;

/**
 * 
 * @author Dani
 */
public interface BFPGUIProgressEventListener {

	/**
	 * This is a function pointer type for a BSP's GUI event handler function
	 * that is to handle GUI progress event notification callbacks coming from a
	 * BFP. In order to receive GUI progress event notifications, a BSP shall
	 * register a callback function of type GUI_PROGRESS_EVENT_HANDLER by
	 * providing the callback address of the function, along with a context
	 * address, in a call to SubscribeToGUIEvents. <br/>
	 * The framework makes a callback to an application function of this type
	 * each time it receives an incoming callback to a function of type
	 * GUI_PROGRESS_EVENT_HANDLER which it exposes to a BFP. The parameters of
	 * the callback (except Context) shall be set from the parameters of the
	 * incoming callback with the same names; the parameter Context shall be set
	 * from the GUI progress context address originally provided by the BSP in
	 * its call to SubscribeToGUIEvents; and the callback address shall be set
	 * from the GUI progress callback address originally provided by the BSP in
	 * the call to SubscribeToGUIEvents. <br/>
	 * The main purpose of the GUI progress event notification is to send to the
	 * BSP streaming data (as a series of bitmaps) collected by the biometric
	 * sensor. One possible use of this information is for the BSPs to show the
	 * bitmaps to the subject or an operator. The BSP shall respond to each GUI
	 * progress notification by indicating whether the biometric capture should
	 * continue or abort. <br/>
	 * The GUI progress event handler function and any functions invoked
	 * (directly or indirectly) by that function shall not call any BioSFPI
	 * function.
	 * 
	 * @param unitID
	 *            The unit ID of the biometric sensor unit of the BSP to which
	 *            the GUI event is related.
	 * @param context
	 *            The context address originally provided by the subscriber
	 *            application as part of the GUI event subscription
	 * @param bitmaps
	 *            An array of bitmaps containing image(s) of the samples
	 *            captured in the biometric capture, which are intended for
	 *            display to the subject or to an operator. This array usually
	 *            contains zero or one bitmaps, but may contain multiple bitmaps
	 *            if the BFP has the ability to capture multiple instances of a
	 *            biometric modality in a single capture operation
	 * @param response
	 *            A value indicating the response from the BSP to the GUI select
	 *            event notification
	 * @throws BioAPIException
	 *             Thrown if any the parameters is not valid or any other error
	 *             during attachment.
	 */
	void bfpGUIProgressEventCallback(int unitID, String context,
			Vector<GUIBitmap> bitmaps, byte response);

}
