package org.bioapi;

import org.bioapi.data.DataTypes.Facility;

public class BioAPIException extends Exception {

	private static final long serialVersionUID = 1L;

	/* CONSTANTS */
	public static final int bioAPIFrameworkError = 0x00000000;
	public static final int bioAPIBspError = 0x01000000;
	public static final int bioAPIUnitError = 0x02000000;

	/**
	 * General system error; indicates that an operating system or internal
	 * state error has occurred and the system may not be in a known state.
	 */
	public static final int bioAPIErrInternalError = 0x000101;

	/**
	 * A memory error occurred.
	 */
	public static final int bioAPIErrMemoryError = 0x000102;

	/**
	 * An input/output function parameter or input/output field inside of a data
	 * structure is an invalid pointer.
	 */
	public static final int bioAPIErrInvalidPointer = 0x000103;

	/**
	 * An input function parameter or input field in a data structure is an
	 * invalid pointer.
	 */
	public static final int bioAPIErrInvalidInputPointer = 0x000104;

	/**
	 * An output function parameter or output field in a data structure is an
	 * invalid pointer.
	 */
	public static final int bioAPIErrInvalidOutputPointer = 0x000105;

	/**
	 * The function is not implemented by the biometric service provider.
	 */
	public static final int bioAPIErrFunctionNotSupported = 0x000106;

	/**
	 * The operating system denied access to a required resource.
	 */
	public static final int bioAPIErrOAccessDenied = 0x000107;

	/**
	 * The function failed for an unknown reason.
	 */
	public static final int bioAPIErrFunctionFailed = 0x000108;

	/**
	 * An input uuid is invalid. [may occur of a component requested by the uuid
	 * is not present on the system or cannot be found.
	 */
	public static final int bioAPIErrInvalidUUID = 0x000109;

	/**
	 * Version incompatibility. [may occur if the called component cannot
	 * support the version of the BioAPI specification expected by the
	 * application.]
	 */
	public static final int bioAPIErrIncompatibleVersion = 0x00010a;

	/**
	 * The data in an input parameter is invalid.
	 */
	public static final int bioAPIErrInvalidData = 0x00010b;

	/**
	 * The associated bsp is unable to capture raw samples from the requested
	 * BioAPI unit.
	 */
	public static final int bioAPIErrUnableToCapture = 0x00010c;

	/**
	 * The associated bsp has no more space to allocated bir handles.
	 */
	public static final int bioAPIErrTooManyHandles = 0x00010d;

	/**
	 * The function has been terminated because the timeout value has expired.
	 */
	public static final int bioAPIErrTimeoutExpired = 0x00010e;

	/**
	 * The input bir is invalid for the purpose required.
	 */
	public static final int bioAPIErrInvalidBir = 0x00010f;

	/**
	 * The associated bsp could not validate the signature on the bir.
	 */
	public static final int bioAPIErrBirSignatureFailure = 0x000110;

	/**
	 * The associated bsp is unable to store the payload.
	 */
	public static final int bioAPIErrUnableToStorePayload = 0x000111;

	/**
	 * The identity population is null.
	 */
	public static final int bioAPIErrNoInputBIRs = 0x000112;

	/**
	 * The associated bsp does not support the bdb requests.
	 */
	public static final int bioAPIErrUnsupportedFormat = 0x000113;

	/**
	 * The associated bsp was unable to finalruct a bir from the input data.
	 */
	public static final int bioAPIErrUnableToImport = 0x000114;

	/**
	 * The purpose recorded in the bir and/or the requested purpose are
	 * inconsistent with the function being performed.
	 */
	public static final int bioAPIErrInconsistentPurpose = 0x000115;

	/**
	 * The function requires a fully processed bir.
	 */
	public static final int bioAPIErrBIRNotFullyProcessed = 0x000116;

	/**
	 * The bsp does not support the requested purpose.
	 */
	public static final int bioAPIErrPurposeNotSupported = 0x000117;

	/**
	 * User cancelled operation before completion or timeout.
	 */
	public static final int bioAPIErrUserCancelled = 0x000118;

	/**
	 * Bsp (or BioAPI unit attached to bsp) is currently being used by another
	 * biometric application.
	 */
	public static final int bioAPIErrUnitInUse = 0x000119;

	/**
	 * The given bsp handle is invalid
	 */
	public static final int bioAPIErrInvalidBSPHandle = 0x00011a;

	/**
	 * A function has been called without initialized the BioAPI framework.
	 */
	public static final int bioAPIErrFrameworkNotInitialized = 0x00011b;

	/**
	 * Bir handle is invalid (does not exist or has not been released).
	 */
	public static final int bioAPIErrInvalidBIRHandle = 0x00011c;

	/**
	 * The attempted calibration of a sensor unit was not able to be
	 * successfully completed.
	 */
	public static final int bioAPIErrCalibrationNotSuccessful = 0x00011d;

	/**
	 * No preset bir population has been established.
	 */
	public static final int bioAPIErrPresetBIRDoesNotExist = 0x00011e;

	/**
	 * The bsp could not decrypt an input bir (and thus was unable to use it for
	 * the related operation).
	 */
	public static final int bioAPIErrDecryptionFailure = 0x00011f;

	public static final int bioAPIErrIdentifyInProgress = 0x000120;

	public static final int bioAPIErrLowQualityReferenceTemplate = 0x000121;

	public static final int bioAPIErrNoGUIEventHandler = 0x000122;

	public static final int bioAPIErrTransformationNotSupported = 0x000123;

	public static final int bioAPIErrInvalidAttachSession = 0x000124;

	public static final int bioAPIErrComponentAlreadyRegistered = 0x000125;

	public static final int bioAPIErrComponentNotRegistered = 0x000126;

	public static final int bioAPIErrAlgorithmNotSupported = 0x000127;

	public static final int bioAPIErrEncodingError = 0x000128;

	public static final int bioAPIErrDecodingError = 0x000129;

	public static final int bioAPIErrConfigurationError = 0x00012a;

	public static final int bioAPIErrSegmentationError = 0x00012b;

	public static final int bioAPIErrSecurityBlockError = 0x00012c;

	public static final int bioAPIErrDataNotFreed = 0x00012d;

	public static final int bioAPIErrDataCreationError = 0x00012e;

	public static final int bioAPIErrWrongBiometricInstancesDetected = 0x00012f;

	/**
	 * A reference to the file or the component being loaded cannot be found.
	 */
	public static final int bioAPIErrComponentFileRefNotFound = 0x000201;

	/**
	 * Framework was unable to successfully load the bsp.
	 */
	public static final int bioAPIErrBSPLoadFail = 0x000202;

	/**
	 * Bsp for which an action was requested is not loaded.
	 */
	public static final int bioAPIErrBSPNotLoaded = 0x000203;

	/**
	 * BioAPI unit for which an action was not requested is not in the inserted
	 * state.
	 */
	public static final int bioAPIErrUnitNotInserted = 0x000204;

	/**
	 * An invalid BioAPI unit id was requested.
	 */
	public static final int bioAPIErrInvalidUnitID = 0x000205;

	/**
	 * An invalid category of bfp or BioAPI unit was requested.
	 */
	public static final int bioAPIErrInvalidCategory = 0x000206;

	/**
	 * Invalid database handle.
	 */
	public static final int bioAPIErrInvalidDBHandle = 0x000300;

	/**
	 * The associated bsp is unable to open the specified database.
	 */
	public static final int bioAPIErrUnableToOpenDatabase = 0x000301;

	/**
	 * The database cannot be opened for the access requested because it is
	 * locked.
	 */
	public static final int bioAPIErrDatabaseIsLocked = 0x000302;

	/**
	 * The specified database does not exist.
	 */
	public static final int bioAPIErrDatabaseDoesNotExist = 0x000303;

	/**
	 * Create failed because the database already exists.
	 */
	public static final int bioAPIErrDatabaseAlreadyExists = 0x000304;

	/**
	 * Invalid database name (uuid)
	 */
	public static final int bioAPIErrInvalidDatabaseName = 0x000305;

	/**
	 * No record exists with the requested key.
	 */
	public static final int bioAPIErrRecordNotFound = 0x000306;

	/**
	 * The specified marker handled is invalid.
	 */
	public static final int bioAPIErrMarkerHandleIsInvalid = 0x000307;

	/**
	 * The database is already open.
	 */
	public static final int bioAPIErrDatabaseIsOpen = 0x000308;

	/**
	 * Unrecognized access type.
	 */
	public static final int bioAPIErrInvalidAccessRequest = 0x000309;

	/**
	 * End of database has been reached.
	 */
	public static final int bioAPIErrEndOfDatabase = 0x00030a;

	/**
	 * The associated bsp cannot create the database.
	 */
	public static final int bioAPIErrUnableToCreateDatabase = 0x00030b;

	/**
	 * The associated bsp cannot close the database.
	 */
	public static final int bioAPIErrUnableToCloseDatabase = 0x00030c;

	/**
	 * The associated bsp cannot delete the database.
	 */
	public static final int bioAPIErrUnableToDeleteDatabase = 0x00030d;

	/**
	 * The specified database is corrupt.
	 */
	public static final int bioAPIErrDatabaseIsCorrupt = 0x00030e;

	public static final int bioAPIErrQueryExecutionFailed = 0x00030f;

	/**
	 * A general location error.
	 */
	public static final int bioAPIErrLocationError = 0x000400;

	/**
	 * Invalid horizontal or vertical position.
	 */
	public static final int bioAPIErrOutOfFrame = 0x000401;

	/**
	 * Invalid crosswise position.
	 */
	public static final int bioAPIErrInvalidCrosswisePosition = 0x000402;

	/**
	 * Invalid lengthwise position.
	 */
	public static final int bioAPIErrInvalidLengthwisePosition = 0x000403;

	/**
	 * Invalid distance.
	 */
	public static final int bioAPIErrInvalidDistance = 0x000404;

	/**
	 * The position was too far to the right.
	 */
	public static final int bioAPIErrLocationTooRight = 0x000405;

	/**
	 * The position was too far to the left.
	 */
	public static final int bioAPIErrLocationTooLeft = 0x000406;

	/**
	 * The position was too high.
	 */
	public static final int bioAPIErrLocationTooHigh = 0x000407;

	/**
	 * The position was too low.
	 */
	public static final int bioAPIErrLocationTooLow = 0x000408;

	/**
	 * The position was too far away.
	 */
	public static final int bioAPIErrLocationTooFar = 0x000409;

	/**
	 * The position was too near (close).
	 */
	public static final int bioAPIErrLocationTooNear = 0x00040a;

	/**
	 * The position was too far foward.
	 */
	public static final int bioAPIErrLocationTooForward = 0x00040b;

	/**
	 * The position was too far backward
	 */
	public static final int bioAPIErrLocationTooBackward = 0x00040c;

	/**
	 * Sample quality is too poor for the operation to succeed. note: quality
	 * errors can be returned from any function which received a BioAPI bir
	 * input.
	 */
	public static final int bioAPIErrQualityError = 0x000501;

	public static final int bioAPIErrTooEarly = 0x000502;

	public static final int bioAPIErrTooLate = 0x000503;

	public static final int bioAPIErrTooFast = 0x000504;

	public static final int bioAPIErrTooSlow = 0x000505;

	public static final int bioAPIErrTooLong = 0x000506;

	public static final int bioAPIErrTooShort = 0x000507;

	public static final int bioAPIErrTooLarge = 0x000508;

	public static final int bioAPIErrTooSmall = 0x000509;

	public static final int bioAPIErrSecurityProfileNotSet = 0x000601;

	public static final int bioAPIErrSecurityEncryptionAlgNotSupported = 0x000610;

	public static final int bioAPIErrSecurityEncryptionAlgNotSet = 0x000611;

	public static final int bioAPIErrSecurityEnckeyNotSet = 0x000612;

	public static final int bioAPIErrSecurityEncryptionFailure = 0x000614;

	protected Facility source;
	protected int errorCode;

	/**
	 * Creates a new instance of BioAPIException with the specified error source
	 * and source number
	 * 
	 * @param source
	 *            The facility that generated the error
	 * @param code
	 *            The error code to be reported
	 */
	public BioAPIException(Facility source, int code) {
		this.source = source;
		this.errorCode = code;
	}

	/**
	 * Creates a new instance of BioAPIException with the specified error
	 * source, source number, and message to be displayed
	 * 
	 * @param source
	 *            The facility that generated the error
	 * @param code
	 *            The error code to be reported
	 * @param message
	 *            A text message to be reported
	 */
	public BioAPIException(Facility source, int code, String message) {
		super(message);
		this.source = source;
		this.errorCode = code;
	}

	/**
	 * Creates a new instance of BioAPIException with the specified error
	 * source, source number, message to be displayed, and cause
	 * 
	 * @param source
	 *            The facility that generated the error
	 * @param code
	 *            The facility that generated the error
	 * @param message
	 *            A text message to be reported
	 * @param cause
	 *            The non-BioAPI exception occurred
	 */
	public BioAPIException(Facility source, int code, String message,
			Exception cause) {
		super(message, cause);
		this.source = source;
		this.errorCode = code;
	}

	/**
	 * Creates a new instance of BioAPIException with the specified error
	 * source, source number, and cause
	 * 
	 * @param source
	 *            The facility that generated the error
	 * @param code
	 *            The error code to be reported
	 * @param cause
	 *            The non-BioAPI exception occurred
	 */
	public BioAPIException(Facility source, int code, Exception cause) {
		super(cause);
		this.source = source;
		this.errorCode = code;
	}

	/**
	 * Get the component that reported an error
	 * 
	 * @return The ID of the component of the biometric system that reported the
	 *         error
	 */
	public Facility getSource() {
		return source;
	}

	/**
	 * Get the error code that identifies the reason of the error
	 * 
	 * @return The numeric code for the error
	 */
	public int getErrorCode() {
		return errorCode;
	}

}
