package org.bioapi.data;

import java.util.UUID;
import java.util.Vector;
import org.bioapi.data.DataTypes.BiometricType;
import org.bioapi.data.DataTypes.UnitCategoryType;

/**
 * Represents the record in the component registry that defines the properties
 * of the BFP installed in the system.
 */
public class BFPSchema {

	private UUID bfpUUID;
	private UnitCategoryType categoryType;
	private String bfpDescription;
	private String path;
	private String specVersion;
	private String productVersion;
	private String vendor;
	private Vector<DataFormat> bfpSupportedFormat;
	private Vector<BiometricType> factorsMask;
	private UUID fwPropertyID;
	private byte[] fwProperty;

	public BFPSchema(UUID bfpUUID, UnitCategoryType categoryType,
			String bfpDescription, String path, String specVersion,
			String productVersion, String vendor,
			Vector<DataFormat> bfpSupportedFormat,
			Vector<BiometricType> factorsMask, UUID fwPropertyID,
			byte[] fwProperty) {
		this.bfpUUID = bfpUUID;
		this.categoryType = categoryType;
		this.bfpDescription = bfpDescription;
		this.path = path;
		this.specVersion = specVersion;
		this.productVersion = productVersion;
		this.vendor = vendor;
		this.bfpSupportedFormat = bfpSupportedFormat;
		this.factorsMask = factorsMask;
		this.fwPropertyID = fwPropertyID;
		this.fwProperty = fwProperty;
	}

	public UUID getBFPUUID() {
		return bfpUUID;
	}

	public UnitCategoryType getCategoryType() {
		return categoryType;
	}

	public String getBFPDescription() {
		return bfpDescription;
	}

	public String getPath() {
		return path;
	}

	public String getSpecVersion() {
		return specVersion;
	}

	public String getProductVersion() {
		return productVersion;
	}

	public String getVendor() {
		return vendor;
	}

	public Vector<DataFormat> getBFPSupportedFormat() {
		return bfpSupportedFormat;
	}

	public Vector<BiometricType> getFactorsMask() {
		return factorsMask;
	}

	public UUID getFWPropertyID() {
		return fwPropertyID;
	}

	public byte[] getFWProperty() {
		return fwProperty;
	}

}
