package org.bioapi.data;

import java.util.UUID;
import java.util.Vector;
import org.bioapi.data.DataTypes.BSPSchemaOperations;
import org.bioapi.data.DataTypes.BSPSchemaOptions;
import org.bioapi.data.DataTypes.BiometricType;

/**
 * Represents the record in the component registry that defines properties of
 * the BSP installed in the system. For security reasons no methods to modify
 * the existing BSPSchema object are provided. Instead, an application should
 * use the corresponding method of the DataFactory to create new BSPSchema
 * containing modified data.
 * 
 * @author See CREDITS.txt
 */
public class BSPSchema {

	private UUID bspUUID;
	private String bspDescription;
	private String path;
	private String specVersion;
	private String productVersion;
	private String vendor;
	private Vector<DataFormat> bspSupportedFormats;
	private Vector<BiometricType> factorsMask;
	private Vector<BSPSchemaOperations> operations;
	private Vector<BSPSchemaOptions> options;
	private int payloadPolicy;
	private int maxPayloadSize;
	private int defaultVerifyTimeout;
	private int defaultIdentifyTimeout;
	private int defaultCaptureTimeout;
	private int defaultEnrolTimeout;
	private int defaultCalibrateTimeout;
	private int maxBSPDbSize;
	private int maxIdentify;
	private int maxNumEnrolInstances;
	private byte[] hostingEndpointIRI;
	private UUID bspAccessUUID;
	private Vector<DataFormat> bspSupportedAlgorithms;
	private Vector<UUID> bspSupportedTransformOperations;

	public BSPSchema(UUID bspUUID, String bspDescription, String path,
			String specVersion, String productVersion, String vendor,
			Vector<DataFormat> bspSupportedFormats,
			Vector<BiometricType> factorsMask,
			Vector<BSPSchemaOperations> operations,
			Vector<BSPSchemaOptions> options, int payloadPolicy,
			int maxPayloadSize, int defaultVerifyTimeout,
			int defaultIdentifyTimeout, int defaultCaptureTimeout,
			int defaultEnrolTimeout, int defaultCalibrateTimeout,
			int maxBSPDbSize, int maxIdentify, int maxNumEnrolInstances,
			byte[] hostingEndpointIRI, UUID bspAccessUUID,
			Vector<DataFormat> bspSupportedAlgorithms,
			Vector<UUID> bspSupportedTransformOperations) {
		this.bspUUID = bspUUID;
		this.bspDescription = bspDescription;
		this.path = path;
		this.specVersion = specVersion;
		this.productVersion = productVersion;
		this.vendor = vendor;
		this.bspSupportedFormats = bspSupportedFormats;
		this.factorsMask = factorsMask;
		this.operations = operations;
		this.options = options;
		this.payloadPolicy = payloadPolicy;
		this.maxPayloadSize = maxPayloadSize;
		this.defaultVerifyTimeout = defaultVerifyTimeout;
		this.defaultIdentifyTimeout = defaultIdentifyTimeout;
		this.defaultCaptureTimeout = defaultCaptureTimeout;
		this.defaultEnrolTimeout = defaultEnrolTimeout;
		this.defaultCalibrateTimeout = defaultCalibrateTimeout;
		this.maxBSPDbSize = maxBSPDbSize;
		this.maxIdentify = maxIdentify;
		this.maxNumEnrolInstances = maxNumEnrolInstances;
		this.hostingEndpointIRI = hostingEndpointIRI;
		this.bspAccessUUID = bspAccessUUID;
		this.bspSupportedAlgorithms = bspSupportedAlgorithms;
		this.bspSupportedTransformOperations = bspSupportedTransformOperations;
	}

	public UUID getBSPUUID() {
		return bspUUID;
	}

	public String getBSPDescription() {
		return bspDescription;
	}

	public String getPath() {
		return path;
	}

	public String getSpecVersion() {
		return specVersion;
	}

	public String getProductVersion() {
		return productVersion;
	}

	public String getVendor() {
		return vendor;
	}

	public Vector<DataFormat> getBSPSupportedFormats() {
		return bspSupportedFormats;
	}

	public Vector<BiometricType> getFactorsMask() {
		return factorsMask;
	}

	public Vector<BSPSchemaOperations> getOperations() {
		return operations;
	}

	public Vector<BSPSchemaOptions> getOptions() {
		return options;
	}

	public int getPayloadPolicy() {
		return payloadPolicy;
	}

	public int getMaxPayloadSize() {
		return maxPayloadSize;
	}

	public int getDefaultVerifyTimeout() {
		return defaultVerifyTimeout;
	}

	public int getDefaultIdentifyTimeout() {
		return defaultIdentifyTimeout;
	}

	public int getDefaultCaptureTimeout() {
		return defaultCaptureTimeout;
	}

	public int getDefaultEnrolTimeout() {
		return defaultEnrolTimeout;
	}

	public int getDefaultCalibrateTimeout() {
		return defaultCalibrateTimeout;
	}

	public int getMaxBSPDbSize() {
		return maxBSPDbSize;
	}

	public int getMaxIdentify() {
		return maxIdentify;
	}

	public int getMaxNumEnrolInstances() {
		return maxNumEnrolInstances;
	}

	public byte[] getHostingEndpointIRI() {
		return hostingEndpointIRI;
	}

	public UUID getBSPAccessUUID() {
		return bspAccessUUID;
	}

	public Vector<DataFormat> getBSPSupportedAlgorithms() {
		return bspSupportedAlgorithms;
	}

	public Vector<UUID> getBSPSupportedTransformOperations() {
		return bspSupportedTransformOperations;
	}

}
