package org.bioapi.data;

public class DataTypes {

	/**
	 * Type of the biometric data used (e.g. modality). When transferring this
	 * information into/from a binary format, the Biometric Type constants
	 * defined in ISO/IEC 30106-1 shall be used.
	 */
	public enum BiometricType {
		NO_VALUE_AVAILABLE(0x00000000), MULTIPLE_BIOMETRIC_TYPES(0x00000001), FACE(
				0x00000002), VOICE(0x00000004), FINGER(0x00000008), IRIS(
				0x00000010), RETINA(0x00000020), HAND_GEOMETRY(0x00000040), SIGNATURE_OR_SIGN(
				0x00000080), KEYSTROKE(0x00000100), LIP_MOVEMENT(0x00000200), GAIT(
				0x00001000), VEIN(0x00002000), DNA(0x00004000), EAR(0x00008000), FOOT(
				0x00010000), SCENT(0x00020000);

		private int value;

		private BiometricType(int value) {
			this.value = value;
		}

		public int getValue() {
			return value;
		}

		public static BiometricType getType(int value) {
			switch (value) {
			case 0x00000000:
				return NO_VALUE_AVAILABLE;
			case 0x00000001:
				return MULTIPLE_BIOMETRIC_TYPES;
			case 0x00000002:
				return FACE;
			case 0x00000004:
				return VOICE;
			case 0x00000008:
				return FINGER;
			case 0x00000010:
				return IRIS;
			case 0x00000020:
				return RETINA;
			case 0x00000040:
				return HAND_GEOMETRY;
			case 0x00000080:
				return SIGNATURE_OR_SIGN;
			case 0x00000100:
				return KEYSTROKE;
			case 0x00000200:
				return LIP_MOVEMENT;
			case 0x00001000:
				return GAIT;
			case 0x00002000:
				return VEIN;
			case 0x00004000:
				return DNA;
			case 0x00008000:
				return EAR;
			case 0x00010000:
				return FOOT;
			case 0x00020000:
				return SCENT;
			default:
				return null;
			}
		}

	}

	/**
	 * Subtype of the biometric data used (e.g. which finger used in finger
	 * modalities). When transferring this information into/from a binary
	 * format, the Biometric Subtype constants defined in ISO/IEC 30106-1 shall
	 * be used.
	 */
	public enum BiometricSubtype {
		NO_VALUE_AVAILABLE((byte) 0x00), LEFT((byte) 0x01), RIGHT((byte) 0x02), LEFT_THUMB(
				(byte) 0x05), LEFT_INDEX_FINGER((byte) 0x09), LEFT_MIDDLE_FINGER(
				(byte) 0x11), LEFT_RING_FINGER((byte) 0x21), LEFT_LITTLE_FINGER(
				(byte) 0x41), RIGHT_THUMB((byte) 0x06), RIGHT_INDEX_FINGER(
				(byte) 0x0A), RIGHT_MIDDLE_FINGER((byte) 0x12), RIGHT_RING_FINGER(
				(byte) 0x22), RIGHT_LITTLE_FINGER((byte) 0x42), LEFT_PALM(
				(byte) 0x85), LEFT_BACK_OF_HAND((byte) 0x89), LEFT_WRIST(
				(byte) 0x91), RIGHT_PALM((byte) 0x86), RIGHT_BACK_OF_HAND(
				(byte) 0x8A), RIGHT_WRIST((byte) 0x92);

		private byte value;

		private BiometricSubtype(byte value) {
			this.value = value;
		}

		public byte getValue() {
			return value;
		}

		public static BiometricSubtype getType(byte value) {
			switch (value) {
			case (byte) 0x00:
				return NO_VALUE_AVAILABLE;
			case (byte) 0x01:
				return LEFT;
			case (byte) 0x02:
				return RIGHT;
			case (byte) 0x05:
				return LEFT_THUMB;
			case (byte) 0x09:
				return LEFT_INDEX_FINGER;
			case (byte) 0x11:
				return LEFT_MIDDLE_FINGER;
			case (byte) 0x21:
				return LEFT_RING_FINGER;
			case (byte) 0x41:
				return LEFT_LITTLE_FINGER;
			case (byte) 0x06:
				return RIGHT_THUMB;
			case (byte) 0x0A:
				return RIGHT_INDEX_FINGER;
			case (byte) 0x12:
				return RIGHT_MIDDLE_FINGER;
			case (byte) 0x22:
				return RIGHT_RING_FINGER;
			case (byte) 0x42:
				return RIGHT_LITTLE_FINGER;
			case (byte) 0x85:
				return LEFT_PALM;
			case (byte) 0x89:
				return LEFT_BACK_OF_HAND;
			case (byte) 0x91:
				return LEFT_WRIST;
			case (byte) 0x86:
				return RIGHT_PALM;
			case (byte) 0x8A:
				return RIGHT_BACK_OF_HAND;
			case (byte) 0x92:
				return RIGHT_WRIST;
			default:
				return null;
			}
		}
	}

	/**
	 * Add the specified BIR to database -READ: The access mode that allows to
	 * retrieve records but probiits any modifications of the databse.</br>
	 * -READ_WRITE: The access mode that allows bot the record retrieval and
	 * that modifications or the database.</br> -WRITE: The access mode that
	 * allows t add and delete records from the databse but prohibits retrieval
	 * of records.
	 * 
	 * @author See CREDITS.txt
	 */
	public enum BIRDatabaseAccess {
		READ, READ_WRITE, WRITE
	}

	/**
	 * Defines the purpose for which the BIR or process is intended
	 */
	public enum BIRPurpose {
		AUDIT, ENROL, ENROL_FOR_IDENTIFICATION_ONLY, ENROL_FOR_VERIFICATION_ONLY, IDENTIFY, VERIFY, DECIDE, NO_PURPOSE_AVAILABLE
	}

	/**
	 * Enumerates the different operations that a BSP can offer to the biometric
	 * application
	 */
	public enum BSPSchemaOperations {
		CALIBRATE_SENSOR(0x0020000), CAPTURE(0x00000004), CHECK_QUALITY(
				0x00080000), CONTROL_UNIT(0x00400000), CREATE_TEMPLATE(
				0x00000008), CREATE_TEMPLATE_WITH_AUX_BIR(0x00000020), DATABASE_OPERATIONS(
				0x00002000), DECIDE(0x04000000), ENABLE_EVENTS(0x00000001), ENROL(
				0x00000100), EXPORT(0x20000000), FUSE(0x08000000), GET_INDICATOR_STATUS(
				0x00010000), IDENTIFY(0x00000080), IDENTIFY_AGGREGATE(
				0x00000400), IMPORT(0x00000800), PRESET_IDENTIFY_POPULATION(
				0x00001000), PROCESS(0x00000010), PROCESS_WITH_AUX_BIR(
				0x01000000), QUERY_BFPS(0x00200000), QUERY_UNITS(0x00100000), SECURITY(
				0x10000000), SET_INDICATOR_STATUS(0x00008000), SET_POWER_MODE(
				0x00004000), TRANSFORM(0x00800000), UTILITIES(0x00040000), VERIFY(
				0x00000040), VERIFY_AGGREGATED(0x00000200), VERIFY_WITH_AUX_BIR(
				0x02000000);

		private int value;

		private BSPSchemaOperations(int value) {
			this.value = value;
		}

		public int getValue() {
			return value;
		}
	}

	/**
	 * Enumerates the different options that can a handle a BSP
	 */
	public enum BSPSchemaOptions {
		ADAPTATION(0x00000800), APP_GUI(0x00000010), ARCHIVE_BFP(0x00020000), BINNING(
				0x00001000), BIR_ENCRYPT(0x00000200), BIR_SIGN(0x00000100), CAPTURE_MULTIPLE(
				0x00400000), COARSE_SCORES(0x00100000), COMPARISON_BFP(
				0x00040000), GUI_PROGRESS_EVENTS(0x00000020), IDENTIFY_INDICATOR(
				0x00200000), OCC(0x00004000), PAYLOAD(0x00000080), PROCESSING_BFP(
				0x00080000), PROCESS_MULTIPLE(0x00800000), QUALITY_INTERMEDIATE(
				0x00000004), QUALITY_PROCESSED(0x00000008), QUALITY_RAW(
				0x00000002), RAW(0x00000001), SELF_CONTAINED_DEVICE(0x00002000), SENSOR_BFP(
				0x00010000), SOURCE_PRESENT(0x00000040), SUBTYPE_TO_CAPTURE(
				0x00008000), TEMPLATE_UPDATE(0x00000400);

		private int value;

		private BSPSchemaOptions(int value) {
			this.value = value;
		}

		public int getValue() {
			return value;
		}
	}

	/**
	 * Defines the kind of sources that can originate an event
	 */
	public enum EventKind {
		FAULT(0x00000004), INSERT(0x00000001), REMOVE(0x00000002), SOURCE_PRESENT(
				0x00000008), SOURCE_REMOVED(0x00000010);

		private int value;

		private EventKind(int value) {
			this.value = value;
		}

		public int getValue() {
			return value;
		}
	}

	/**
	 * Defines originator of the error in a exception
	 */
	public enum Facility {
		FRAMEWORK, BSP, UNIT
	}

	/**
	 * Indicates the enrol type of a BSP
	 */
	public enum GUIEnrolType {
		TEST_VERIFY, MULTIPLE_CAPTURE
	}

	/**
	 * Determines the moment when the processing of an operation is at the time
	 * of calling a GUI callback function
	 */
	public enum GUIMoment {
		BEFORE_START, AFTER_END
	}

	/**
	 * Determines the operation being performed when using GUI callback
	 * functions
	 */
	public enum GUIOperation {
		CAPTURE, ENROL, IDENTIFY, VERIFY
	}

	/**
	 * Enumeration of the possible actions to be performed by a BSP after a GUI
	 * event notification callback made by the BSP has returned control to the
	 * BSP
	 */
	public enum GUIResponse {
		CYCLE_START, CYCLE_RESTART, DEFAULT, OP_COMPLETE, OP_CANCEL, PROGRESS_CONTINUE, PROGRESS_ABORT, RECAPTURE, SUB_OP_START, SUB_OP_NEXT
	}

	/**
	 * An enumeration of the possible types of suboperations performed by a BSP
	 * during an operation, to be reported to the application in GUI event
	 * notifications
	 */
	public enum GUISuboperation {
		CAPTURE, CREATE_TEMPLATE, IDENTIFY, PROCESS, VERIFY
	}

	/**
	 * Determines the level of processing of the BIR
	 */
	public enum ProcessedLevel {
		RAW((byte) 0x01), INTERMEDIATE((byte) 0x02), PROCESSED((byte) 0x03);

		private byte value;

		private ProcessedLevel(byte value) {
			this.value = value;
		}

		public byte getValue() {
			return value;
		}
	}

	/**
	 * Defines the request to some BioAPI methods, to provide additional results
	 * to the originally defined </br> -REQUEST_ADAPTED_BIR: Request that a BIR
	 * be constructed by adapting the reference template using the processed BIR
	 * that is the input to the biometric verification. </br> -REQUEST_PAYLOAD:
	 * Request that the payload should be returned upon successful verification
	 * if the achieved. </br> -REQUEST_AUDDITIONAL_DATA: Request additional data
	 * to be used, for example, in an auditing process.
	 */
	public enum ResultOptions {
		REQUEST_ADAPTED_BIR, REQUEST_PAYLOAD, REQUEST_AUDDITIONAL_DATA
	}

	/**
	 * Defines which security options are supported by the BioAPI_Unit </br>
	 * -ENCRYPTION: Indicates that the BioAPI Unit supports encryption. -MAC:
	 * Indicates that the BioAPI Unit supports MAC generation. </br>
	 * -DIGITAL_SIGNATURE: Indicates that the BioAPI Unit supports digital
	 * signature. </br> -AC_BIO_GENERATION_WITH_MAC: Indicates that the BioAPI
	 * Unit supports ACBio generation using MAC. </br>
	 * -AC_BIO_GENERATION_WITH_DIGITAL_SIGNATURE: Indicates that the BioAPI Unit
	 * supports ACBio generation using digital signature.
	 */
	public enum SecurityOptionsType {
		ENCRYPTION(0x00000001), MAC(0x00000002), DIGITAL_SIGNATURE(0x00000004), AC_BIO_GENERATION_WITH_MAC(
				0x00000010), AC_BIO_GENERATION_WITH_DIGITAL_SIGNATURE(
				0x00000020);

		private int value;

		private SecurityOptionsType(int value) {
			this.value = value;
		}

		public int getValue() {
			return value;
		}
	}

	/**
	 * Defines possible unit categories. </br> -ARCHIVE: The unit manages BSP's
	 * BIR database. </br> -COMPARISON: The unit is the collection of comparison
	 * algorithms. </br> -PROCESSING: The unit is the collection of processing
	 * algorithms. </br> -SENSOR: The unit manages hardware sensor.
	 */
	public enum UnitCategoryType {
		ARCHIVE(0x00000001), COMPARISON(0x00000002), PROCESSING(0x00000004), SENSOR(
				0x00000008);

		private int value;

		private UnitCategoryType(int value) {
			this.value = value;
		}

		public int getValue() {
			return value;
		}
	}

	/**
	 * Defines possible values of indicator status.
	 */
	public enum UnitIndicatorStatus {
		ACCEPT, BUSY, FAILURE, READY, REJECT
	}

	/**
	 * Defines unit power modes. </br> -DETECT: mode when unit is able to detect
	 * interaction of subject with the sensor. </br> -NORMAL: mode when all
	 * functions are available. </br> -SLEEP: minimum mode. All functions off.
	 */
	public enum UnitPowerMode {
		DETECT, NORMAL, SLEEP
	}

}
