package org.bioapi.data;

import java.util.Vector;
import org.bioapi.BioAPIException;

/**
 * Address and length of a memory buffer containing the Framework property. The
 * format and content of the Framework property can either be specified by a
 * vendor or can be specified in a related standard.
 */
public class IdentifyPopulation {

	private Vector<PopulationMember> identifyPopulation;

	public IdentifyPopulation() {
		identifyPopulation = new Vector<PopulationMember>();
	}

	public IdentifyPopulation(Vector<PopulationMember> identifyPopulation) {
		this.identifyPopulation = identifyPopulation;
	}

	public Vector<PopulationMember> getIdentifyPopulation() {
		return identifyPopulation;
	}

	/**
	 * Add a new member to the population to be used for identification
	 * purposes. Sucessive calls to this method fills in the List of the
	 * population members
	 * 
	 * @param member
	 *            the member to be added.
	 * @throws BioAPIException
	 *             If input parameters are invalid or operation fails due to an
	 *             error.
	 */
	void addMember(PopulationMember member) throws BioAPIException {
		identifyPopulation.add(member);
	}

	/**
	 * Removes all the information of the list of the population used for
	 * identification.
	 * 
	 * @throws BioAPIException
	 */
	void destroy() throws BioAPIException {
		identifyPopulation = null;
	}

	/**
	 * True if at least one BIR in the population is bound to the BSP
	 * 
	 * @return True if it is bound, false in any other case
	 */
	boolean isBound() {
		return false;
	}

	/**
	 * Ensures that all member BIRs are unbound.
	 * 
	 * @throws BioAPIException
	 *             If operation fails
	 */
	void unbind() throws BioAPIException {
	}

}
