package org.bioapi.data;

import java.util.Vector;
import org.bioapi.data.DataTypes.BSPSchemaOptions;
import org.bioapi.data.DataTypes.SecurityOptionsType;

/**
 * Defines the information of the cryptographic algorithms and keys of a
 * BioAPI_Unit or a biometric application which is used to encrypt/decrypt
 * biometric data or to generate/valDate the MAC or digital signature of the BIR
 * and also givin the information of the hash algorithm, the information about
 * the MAC generation, and the digital signature used in ACBio generation. </br>
 * When this structure is used in the interface UnitSchema as the output
 * parameter of BioAPI_QueryUnits, the parameters in this structure indicate the
 * information supported in the BioAPI_Unit. On the other hand, when this
 * structure is used as the parameter of BSPAttach, the parameters in this
 * structure indicates the information which is to be used in the execution of
 * security operations. More information can be found in ISO/IEC 19784-1.
 */
public class SecurityProfileType {

	private Vector<SecurityOptionsType> supportedSecurityOptions;
	private byte[] encInfo;
	private byte[] macInfo;
	private byte[] signAlg;
	private Vector<BSPSchemaOptions> acBioOption;
	private byte[] hashAlgForACBio;
	private byte[] macInfoForACBio;
	private byte[] signAlgForACBio;

	public SecurityProfileType(
			Vector<SecurityOptionsType> supportedSecurityOptions,
			byte[] encInfo, byte[] macInfo, byte[] signAlg,
			Vector<BSPSchemaOptions> acBioOption, byte[] hashAlgForACBio,
			byte[] macInfoForACBio, byte[] signAlgForACBio) {
		this.supportedSecurityOptions = supportedSecurityOptions;
		this.encInfo = encInfo;
		this.macInfo = macInfo;
		this.signAlg = signAlg;
		this.acBioOption = acBioOption;
		this.hashAlgForACBio = hashAlgForACBio;
		this.macInfoForACBio = macInfoForACBio;
		this.signAlgForACBio = signAlgForACBio;
	}

	public Vector<SecurityOptionsType> getSupportedSecurityOptions() {
		return supportedSecurityOptions;
	}

	public byte[] getEncInfo() {
		return encInfo;
	}

	public byte[] getMacInfo() {
		return macInfo;
	}

	public byte[] getSignAlg() {
		return signAlg;
	}

	public Vector<BSPSchemaOptions> getAcBioOption() {
		return acBioOption;
	}

	public byte[] getHashAlgForACBio() {
		return hashAlgForACBio;
	}

	public byte[] getMacInfoForACBio() {
		return macInfoForACBio;
	}

	public byte[] getSignAlgForACBio() {
		return signAlgForACBio;
	}

}
